Index: trunk/kernel/kern/rpc.h
===================================================================
--- trunk/kernel/kern/rpc.h	(revision 640)
+++ trunk/kernel/kern/rpc.h	(revision 641)
@@ -130,10 +130,10 @@
  * the caller. It exit with a Panic message if remote fifo is still full after 
  * (CONFIG_RPC_PUT_MAX_ITERATIONS) retries. 
- * - When the RPC <blocking> field is true, this function blocks and deschedule. 
- *   It returns only when the server acknowledges the RPC by writing in the RPC
- *   "response" field, and unblocks the client.
+ * - When the RPC <blocking> field is true, this function blocks and deschedule
+ *   the client thread. It returns only when the server completes the RPC and
+ *   unblocks the client thread.
  * - When the <blocking> field is false, this function returns as soon as the RPC
- *   has been registered in the FIFO, and the server thread must directly signal
- *   completion to the client thread.
+ *   has been registered in the FIFO, and the client thread must block itself when
+ *   all RPCS have been registered in all target clusters.
  ***********************************************************************************
  * @ cxy   : server cluster identifier
@@ -520,16 +520,18 @@
 
 /***********************************************************************************
  * [25] The RPC_VMM_RESIZE_VSEG allows a client thread to request a remote vseg
  * resize. Both the VSL and the GPT are updated in the remote cluster. 
  ***********************************************************************************
  * @ cxy         : server cluster identifier.
  * @ process     : [in] local pointer on remote process.
  * @ vseg        : [in] local pointer on remote vseg.
  * @ new_base    : [in] new vseg base address.
  * @ new_size    : [in] new vseg size.
  **********************************************************************************/
 void rpc_vmm_resize_vseg_client( cxy_t              cxy,
-                                 struct process_s * process,
-                                 struct vseg_s    * vseg,
+                                 pid_t              pid,
+                                 intptr_t           base,
                                  intptr_t           new_base,
                                  intptr_t           new_size );
@@ -538,14 +540,16 @@
 
 /***********************************************************************************
- * [26] The RPC_VMM_REMOVE_VSEG allows a client thread  to request a remote vseg
- * delete. Bothe the VSL and the GPT are updated in the remote cluster.
- ***********************************************************************************
- * @ cxy         : server cluster identifier.
- * @ process     : [in] local pointer on remote process.
- * @ vseg        : [in] local pointer on remote vseg.
- **********************************************************************************/
-void rpc_vmm_remove_vseg_client( cxy_t              cxy,
-                                 struct process_s * process,
-                                 struct vseg_s    * vseg );
+ * [26] The RPC_VMM_REMOVE_VSEG allows a client thread  to request a remote cluster
+ * to delete a vseg identified by the <vaddr> argument in a process descriptor
+ * identified by the <pid> argument.
+ * Both the VSL and the GPT are updated in the remote cluster.
+ ***********************************************************************************
+ * @ cxy       : server cluster identifier.
+ * @ pid       : [in] process identifier.
+ * @ base      : [in] vseg base.
+ **********************************************************************************/
+void rpc_vmm_remove_vseg_client( cxy_t      cxy,
+                                 pid_t      pid,
+                                 intptr_t   base );
  
 void rpc_vmm_remove_vseg_server( xptr_t xp );
@@ -520,16 +520,18 @@
 
 /***********************************************************************************
- * [25] The RPC_VMM_RESIZE_VSEG allows a client thread to request a remote vseg
- * resize. Both the VSL and the GPT are updated in the remote cluster. 
+ * [25] The RPC_VMM_RESIZE_VSEG allows a client thread to request a remote cluster
+ * to resize a vseg identified by the <base> argument in a process descriptor
+ * identified by the <pid> argument, as defined by the <new_base> and <new_size>
+ * arguments. Both the VSL and the GPT are updated in the remote cluster. 
  ***********************************************************************************
  * @ cxy         : server cluster identifier.
@@ -520,16 +520,18 @@
  ***********************************************************************************
  * @ cxy         : server cluster identifier.
- * @ process     : [in] local pointer on remote process.
- * @ vseg        : [in] local pointer on remote vseg.
- * @ new_base    : [in] new vseg base address.
+ * @ pid         : [in] process identifier.
+ * @ base        : [in] vseg base.
+ * @ new_base    : [in] new vseg base.
  * @ new_size    : [in] new vseg size.
  **********************************************************************************/
